
# Pacotes utilizados para pazer os gr?ficos
require(ggplot2)
require(Rmisc)

setwd("/home/waldecy/Dropbox/Compartilhados/Wellington/Threshold/end/R")
data=read.table("Results.txt",head=TRUE)

sig=0.05 #N?vel de Signific?ncia
threshold=seq(from=0.2, to=0.99, by=0.02) #Limites de Threshold

#############################
# Organiza o conjunto de dados e realiza a contagem dos neur?nios
# Realiza o teste de Wilcoxon

i=1
while(i <= nrow(data)){
  data[i,6]=data[i+1,5]/data[i,5]
  i=i+2
}
data<- subset(data, !is.na(data[,6]))

#j=1
l=1
for(j in 1:length(threshold)){
  
  for(i in 1:nrow(data)){
    if(data[i,6]<=threshold[j])
      data[i,7]=1
    else
      data[i,7]=0
  }
  
  aggre1=aggregate(data[,7], by=list(data[,1],data[,2]), sum)
  
  if(j==1){
    result.graph=data.frame(matrix(NA, ncol=3, nrow=nrow(aggre1)*length(threshold)))
    result.count=data.frame(matrix(NA, ncol=(length(threshold)+2), nrow=nrow(aggre1)))
    result.wilcoxon=data.frame(matrix(NA, ncol=3, nrow=length(threshold)))
    result.count[,1]=aggre1[,1];result.count[,2]=aggre1[,2]
    colnames(result.graph)=c("Animals","X","Threshold")
    colnames(result.wilcoxon)=c("Threshold","W","p-value")
    colnames(result.count)=c("Type","Slice",paste("Threshold", threshold*100,sep=""))
  }
  
  result.count[,j+2]=aggre1[,3]
  
  
  for(k in 1:nrow(aggre1)){
    if(aggre1[k,1]==1)
      result.graph[l,1]="EXP"
    else
      result.graph[l,1]="CTRL"
    
    result.graph[l,2]=aggre1[k,3]
    result.graph[l,3]=threshold[j]*100
    w=wilcox.test(aggre1[aggre1[,1]==1,3], aggre1[aggre1[,1]==2,3],alternative="two.side")
    result.wilcoxon[j,1]=threshold[j]*100; result.wilcoxon[j,2]=w$statistic; result.wilcoxon[j,3]=w$p.value 
    l=l+1
  }
}

#resultados do teste de Wilcoxon
write.table(result.wilcoxon,"Resultados Wilcoxon.txt",
            sep="\t",dec=".",quote=TRUE, row.names=FALSE)

#resultados das contagens
write.table(result.count,"Resultados Contagem.txt",
            sep="\t",dec=".",quote=TRUE, row.names=FALSE)

###################     Gr?fico M?dias       ###################

tgc <- summarySE(result.graph, measurevar="X", groupvars=c("Animals","Threshold"))
ggplot(tgc, aes(x=Threshold, y=X, colour=Animals)) + 
  labs(x="Background percentage threshold (%)") +
  labs(y="Average number of the core count of c-Fos positive neurons") +
  geom_errorbar(aes(ymin=X-se, ymax=X+se), colour="black", width=1) +
  theme_bw() +
  geom_point(aes(shape=Animals),size=3, colour="black") +
  annotate("text", x = tgc[(length(subset(result.wilcoxon, result.wilcoxon[,3] > sig)[,1])+1):(length(tgc[,1])/2),2],
           y = tgc[((length(subset(result.wilcoxon, result.wilcoxon[,3] > sig)[,1])+1)+(length(tgc[,1])/2)):
                     (length(tgc[,1])),4]+tgc[((length(subset(result.wilcoxon, result.wilcoxon[,3] > sig)[,1])+1)
                      +(length(tgc[,1])/2)):(length(tgc[,1])),6]+3, label = "*", cex=6)


ggsave(filename = "Error plot.tiff", scale = 1, dpi = 300)

###################     Gr?fico p-valor       ###################

tiff(filename = "P-value.tiff")
plot(result.wilcoxon[,3] ~ result.wilcoxon[,1], type="p", pch=20, 
     xlab="Background percentage threshold (%)", ylab="P value")
lines(c(sig, sig)~c(result.wilcoxon[1,1],result.wilcoxon[length(result.wilcoxon[,1]),1]), lty=3)
dev.off()


######################### An?lise de Agrupamento #########################

# Acredito que essa rotina n?o ir? entrar no artigo, pois funciona apeanas para este conjunto de dados
# Foi feita uma An?lise de Agrupamento, considerando a dist?ncia euclidiana entre os pontos e o m?todo de agrupamento de Ward

library(cluster)
library(vegan)

data<- subset(tgc, Animals=="CTRL")
k=data.frame(data$X, row.names=data$Threshold)
dist1<-vegdist(k$data.X,"euclidean")
clust1<-hclust(dist1,"ward.D")
tiff(filename = "Dendogram.tiff")
plot(clust1, hang=0.05, main='Dendogram') #Gr?fico Dendograma, que resume os agrupamentos
rect.hclust(clust1, k=4, border="red")
dev.off()

y=c(0,13,20,29,40) # Limites dos agrupamentos. Aqui eu considero apenas a ordem no vetor. Esses valores n?o representam nenhuma vari?vel

# Gr?fico com todos os grupos

tgc <- summarySE(result.graph, measurevar="X", groupvars=c("Animals","Threshold"))
ggplot(tgc, aes(x=Threshold, y=X, colour=Animals)) + 
  labs(x="Background percentage threshold (%)") +
  labs(y="Average number of the core count of c-Fos positive neurons") +
  geom_errorbar(aes(ymin=X-se, ymax=X+se), colour="black", width=1) +
  theme_bw() +
  geom_point(aes(shape=Animals),size=3, colour="black") +
  annotate("text", x = tgc[(length(subset(result.wilcoxon, result.wilcoxon[,3] > sig)[,1])+1):(length(tgc[,1])/2),2],
           y = tgc[((length(subset(result.wilcoxon, result.wilcoxon[,3] > sig)[,1])+1)+(length(tgc[,1])/2)):
                     (length(tgc[,1])),4]+tgc[((length(subset(result.wilcoxon, result.wilcoxon[,3] > sig)[,1])+1)
                                               +(length(tgc[,1])/2)):(length(tgc[,1])),6]+3, label = "*", cex=6)+
  annotate("rect", xmin = threshold[y[1]+1]*100,
           xmax = threshold[y[1+1]]*100, alpha = .2,
           ymin = tgc[tgc[,2]==threshold[y[1]+1]*100 & tgc[,1]=="EXP",4]-tgc[tgc[,2]==threshold[y[1]+1]*100 & tgc[,1]=="EXP",6],
           ymax = tgc[tgc[,2]==threshold[y[1+1]]*100 & tgc[,1]=="EXP",4]+tgc[tgc[,2]==threshold[y[1+1]]*100 & tgc[,1]=="EXP",6])+
  annotate("rect", xmin = threshold[y[2]+1]*100,
           xmax = threshold[y[2+1]]*100, alpha = .3,
           ymin = tgc[tgc[,2]==threshold[y[2]+1]*100 & tgc[,1]=="EXP",4]-tgc[tgc[,2]==threshold[y[2]+1]*100 & tgc[,1]=="EXP",6],
           ymax = tgc[tgc[,2]==threshold[y[2+1]]*100 & tgc[,1]=="EXP",4]+tgc[tgc[,2]==threshold[y[2+1]]*100 & tgc[,1]=="EXP",6])+
  annotate("rect", xmin = threshold[y[3]+1]*100,
           xmax = threshold[y[3+1]]*100, alpha = .4,
           ymin = tgc[tgc[,2]==threshold[y[3]+1]*100 & tgc[,1]=="EXP",4]-tgc[tgc[,2]==threshold[y[3]+1]*100 & tgc[,1]=="EXP",6],
           ymax = tgc[tgc[,2]==threshold[y[3+1]]*100 & tgc[,1]=="EXP",4]+tgc[tgc[,2]==threshold[y[3+1]]*100 & tgc[,1]=="EXP",6])+
  annotate("rect", xmin = threshold[y[4]+1]*100,
           xmax = threshold[y[4+1]]*100, alpha = .5,
           ymin = tgc[tgc[,2]==threshold[y[4]+1]*100 & tgc[,1]=="EXP",4]-tgc[tgc[,2]==threshold[y[4]+1]*100 & tgc[,1]=="EXP",6],
           ymax = tgc[tgc[,2]==threshold[y[4+1]]*100 & tgc[,1]=="EXP",4]+tgc[tgc[,2]==threshold[y[4+1]]*100 & tgc[,1]=="EXP",6])


ggsave(filename = "Error plot - Cluster 1.tiff", scale = 1, dpi = 300)

######################### Boxplot #################################


tiff(filename = "Boxplot.tiff")
boxplot(result.count[result.count[,1]==2,31],result.count[result.count[,1]==1,31], xaxt="n",ylab="Average number of the core count of c-Fos positive neurons", xlab="Animals")
axis(1, label=c("CTRL","EXP"),at=c(1,2))
dev.off()




